(function (exports, Tooltip$1) {
    'use strict';

    function run(fn) {
        return fn();
    }
    function blank_object() {
        return Object.create(null);
    }
    function run_all(fns) {
        fns.forEach(run);
    }
    function null_to_empty(value) {
        return value == null ? '' : value;
    }

    let current_component;
    function set_current_component(component) {
        current_component = component;
    }
    const ATTR_REGEX = /[&"]/g;
    const CONTENT_REGEX = /[&<]/g;
    /**
     * Note: this method is performance sensitive and has been optimized
     * https://github.com/sveltejs/svelte/pull/5701
     */
    function escape(value, is_attr = false) {
        const str = String(value);
        const pattern = is_attr ? ATTR_REGEX : CONTENT_REGEX;
        pattern.lastIndex = 0;
        let escaped = '';
        let last = 0;
        while (pattern.test(str)) {
            const i = pattern.lastIndex - 1;
            const ch = str[i];
            escaped += str.substring(last, i) + (ch === '&' ? '&amp;' : (ch === '"' ? '&quot;' : '&lt;'));
            last = i + 1;
        }
        return escaped + str.substring(last);
    }
    function validate_component(component, name) {
        if (!component || !component.$$render) {
            if (name === 'svelte:component')
                name += ' this={...}';
            throw new Error(`<${name}> is not a valid SSR component. You may need to review your build config to ensure that dependencies are compiled, rather than imported as pre-compiled modules. Otherwise you may need to fix a <${name}>.`);
        }
        return component;
    }
    let on_destroy;
    function create_ssr_component(fn) {
        function $$render(result, props, bindings, slots, context) {
            const parent_component = current_component;
            const $$ = {
                on_destroy,
                context: new Map(context || (parent_component ? parent_component.$$.context : [])),
                // these will be immediately discarded
                on_mount: [],
                before_update: [],
                after_update: [],
                callbacks: blank_object()
            };
            set_current_component({ $$ });
            const html = fn(result, props, bindings, slots);
            set_current_component(parent_component);
            return html;
        }
        return {
            render: (props = {}, { $$slots = {}, context = new Map() } = {}) => {
                on_destroy = [];
                const result = { title: '', head: '', css: new Set() };
                const html = $$render(result, props, {}, $$slots, context);
                run_all(on_destroy);
                return {
                    html,
                    css: {
                        code: Array.from(result.css).map(css => css.code).join('\n'),
                        map: null // TODO
                    },
                    head: result.title + result.head
                };
            },
            $$render
        };
    }
    function add_attribute(name, value, boolean) {
        if (value == null || (boolean && !value))
            return '';
        const assignment = (boolean && value === true) ? '' : `="${escape(value, true)}"`;
        return ` ${name}${assignment}`;
    }

    /* src/components/ActionButton.svelte generated by Svelte v3.59.2 */

    const css$1 = {
    	code: "button.svelte-hl54dl.svelte-hl54dl{display:flex;align-items:center;align-content:space-around;position:relative}.spectrum-ActionButton.svelte-hl54dl.svelte-hl54dl{width:var(--width);max-width:100%}.spectrum-ActionButton-label.svelte-hl54dl.svelte-hl54dl{width:auto}.spectrum-ActionButton--emphasized.is-selected.svelte-hl54dl.svelte-hl54dl{background:var(--blue-500)}.spectrum-ActionButton.secondary.svelte-hl54dl.svelte-hl54dl{background:var(--secondary-color)}.spectrum-ActionButton.tertiary.svelte-hl54dl.svelte-hl54dl{background:var(--tertiary-color)}.spectrum-ActionButton.svelte-hl54dl:enabled .spectrum-Icon.svelte-hl54dl{color:var(--iconColor)}",
    	map: "{\"version\":3,\"file\":\"ActionButton.svelte\",\"sources\":[\"ActionButton.svelte\"],\"sourcesContent\":[\"<script>\\n    export let size = \\\"M\\\";\\n    export let groupItem;\\n    export let iconOnly;\\n    export let hideTooltip;\\n    export let hold = false;\\n    export let label;\\n    export let iconName;\\n    export let iconColor;\\n    export let emphasized;\\n    export let quiet;\\n    export let isSelected; \\n    export let disabled;\\n    export let margin;\\n    export let width;\\n    export let secondaryColor = \\\"var(--green-500)\\\";\\n    export let tertiaryColor = \\\"var(--magenta-500)\\\";\\n    export let secondary; \\n    export let tooltipDirection = \\\"auto\\\"; \\n    export let relativeTooltip\\n\\n    import Tooltip from 'Tooltip.svelte';\\n</script>\\n<button \\n    on:click\\n    on:mousedown\\n    on:mouseup \\n    on:dblclick\\n    class=\\\"spectrum-ActionButton spectrum-ActionButton--size{size}\\\" \\n    class:spectrum-ActionButton-iconOnly={iconOnly}\\n    class:spectrum-ActionGroup-item={groupItem}\\n    class:spectrum-ActionButton--emphasized={emphasized} \\n    class:spectrum-ActionButton--quiet={quiet}  \\n    class:is-selected={isSelected} \\n    class:secondary\\n    class:u-tooltip-showOnHover={relativeTooltip}\\n    {disabled}\\n    style=\\\"\\n        --iconColor: {iconColor ? iconColor : \\\"var(--spectrum-actionbutton-m-texticon-icon-color-hover, var(--spectrum-alias-component-icon-color-hover))\\\"};\\n        --secondary-color: {secondaryColor};\\n        --tertiary-color: {tertiaryColor};\\n        {margin ? `margin: ${margin}` : \\\"\\\"};\\n        --width: {width ? width : \\\"inherit\\\"};\\\"\\n    >\\n    {#if hold}\\n        <svg class={`spectrum-Icon spectrum-UIIcon-CornerTriangle${size == \\\"S\\\" ? \\\"75\\\" : \\\"100\\\"} spectrum-ActionButton-hold`} focusable=\\\"false\\\" aria-hidden=\\\"true\\\">\\n            <use xlink:href={`#spectrum-css-icon-CornerTriangle${size == \\\"S\\\" ? \\\"75\\\" : \\\"100\\\"}`} />\\n        </svg>\\n    {/if}\\n    {#if iconName}\\n        <svg class=\\\"spectrum-Icon spectrum-Icon--size{size}\\\" focusable=\\\"false\\\" aria-hidden=\\\"true\\\" aria-label=\\\"Edit\\\">\\n            <use xlink:href=\\\"#spectrum-icon-18-{iconName}\\\" />\\n        </svg>\\n    {/if}\\n    {#if label && !iconOnly}<span class=\\\"spectrum-ActionButton-label\\\">{label}</span>{/if}\\n    <slot></slot>\\n    {#if relativeTooltip}\\n        <div class=\\\"spectrum-Tooltip spectrum-Tooltip--{tooltipDirection === \\\"auto\\\" ? \\\"top\\\" : tooltipDirection}\\\">\\n            <span class=\\\"spectrum-Tooltip-label\\\">{label}</span>\\n            <span class=\\\"spectrum-Tooltip-tip\\\"></span>\\n        </div>\\n    {/if}\\n</button>\\n{#if iconOnly || !hideTooltip && !relativeTooltip}\\n    <Tooltip relative text={label} align={tooltipDirection}></Tooltip> \\n{/if}\\n<style> \\n    button{\\n        display: flex; \\n        align-items: center;\\n        align-content: space-around;\\n        position: relative;\\n    }\\n    .spectrum-ActionButton{\\n        width: var(--width); \\n        max-width: 100%;\\n    }\\n\\n/*\\n    .spectrum-ActionButton-iconOnly .spectrum-Icon{\\n        margin-left: calc(-1 * (var(--spectrum-actionbutton-textonly-padding-left-adjusted) - var(--spectrum-actionbutton-icononly-padding-left-adjusted)));\\n        margin-right: calc(-1 * (var(--spectrum-actionbutton-textonly-padding-right-adjusted) - var(--spectrum-actionbutton-icononly-padding-right-adjusted)));\\n    }*/\\n    .spectrum-ActionButton-label{\\n        width: auto;\\n    }\\n    .spectrum-ActionButton--emphasized.is-selected{\\n        background: var(--blue-500);\\n    }\\n    .spectrum-ActionButton.secondary{\\n        background: var(--secondary-color);\\n    }\\n    .spectrum-ActionButton.tertiary{\\n        background: var(--tertiary-color);\\n    }\\n    .spectrum-ActionButton:enabled .spectrum-Icon{\\n\\t\\tcolor: var(--iconColor);\\n\\t}\\n</style>\"],\"names\":[],\"mappings\":\"AAmEI,kCAAM,CACF,OAAO,CAAE,IAAI,CACb,WAAW,CAAE,MAAM,CACnB,aAAa,CAAE,YAAY,CAC3B,QAAQ,CAAE,QACd,CACA,kDAAsB,CAClB,KAAK,CAAE,IAAI,OAAO,CAAC,CACnB,SAAS,CAAE,IACf,CAOA,wDAA4B,CACxB,KAAK,CAAE,IACX,CACA,kCAAkC,wCAAY,CAC1C,UAAU,CAAE,IAAI,UAAU,CAC9B,CACA,sBAAsB,sCAAU,CAC5B,UAAU,CAAE,IAAI,iBAAiB,CACrC,CACA,sBAAsB,qCAAS,CAC3B,UAAU,CAAE,IAAI,gBAAgB,CACpC,CACA,oCAAsB,QAAQ,CAAC,4BAAc,CAC/C,KAAK,CAAE,IAAI,WAAW,CACvB\"}"
    };

    const ActionButton = create_ssr_component(($$result, $$props, $$bindings, slots) => {
    	let { size = "M" } = $$props;
    	let { groupItem } = $$props;
    	let { iconOnly } = $$props;
    	let { hideTooltip } = $$props;
    	let { hold = false } = $$props;
    	let { label } = $$props;
    	let { iconName } = $$props;
    	let { iconColor } = $$props;
    	let { emphasized } = $$props;
    	let { quiet } = $$props;
    	let { isSelected } = $$props;
    	let { disabled } = $$props;
    	let { margin } = $$props;
    	let { width } = $$props;
    	let { secondaryColor = "var(--green-500)" } = $$props;
    	let { tertiaryColor = "var(--magenta-500)" } = $$props;
    	let { secondary } = $$props;
    	let { tooltipDirection = "auto" } = $$props;
    	let { relativeTooltip } = $$props;
    	if ($$props.size === void 0 && $$bindings.size && size !== void 0) $$bindings.size(size);
    	if ($$props.groupItem === void 0 && $$bindings.groupItem && groupItem !== void 0) $$bindings.groupItem(groupItem);
    	if ($$props.iconOnly === void 0 && $$bindings.iconOnly && iconOnly !== void 0) $$bindings.iconOnly(iconOnly);
    	if ($$props.hideTooltip === void 0 && $$bindings.hideTooltip && hideTooltip !== void 0) $$bindings.hideTooltip(hideTooltip);
    	if ($$props.hold === void 0 && $$bindings.hold && hold !== void 0) $$bindings.hold(hold);
    	if ($$props.label === void 0 && $$bindings.label && label !== void 0) $$bindings.label(label);
    	if ($$props.iconName === void 0 && $$bindings.iconName && iconName !== void 0) $$bindings.iconName(iconName);
    	if ($$props.iconColor === void 0 && $$bindings.iconColor && iconColor !== void 0) $$bindings.iconColor(iconColor);
    	if ($$props.emphasized === void 0 && $$bindings.emphasized && emphasized !== void 0) $$bindings.emphasized(emphasized);
    	if ($$props.quiet === void 0 && $$bindings.quiet && quiet !== void 0) $$bindings.quiet(quiet);
    	if ($$props.isSelected === void 0 && $$bindings.isSelected && isSelected !== void 0) $$bindings.isSelected(isSelected);
    	if ($$props.disabled === void 0 && $$bindings.disabled && disabled !== void 0) $$bindings.disabled(disabled);
    	if ($$props.margin === void 0 && $$bindings.margin && margin !== void 0) $$bindings.margin(margin);
    	if ($$props.width === void 0 && $$bindings.width && width !== void 0) $$bindings.width(width);
    	if ($$props.secondaryColor === void 0 && $$bindings.secondaryColor && secondaryColor !== void 0) $$bindings.secondaryColor(secondaryColor);
    	if ($$props.tertiaryColor === void 0 && $$bindings.tertiaryColor && tertiaryColor !== void 0) $$bindings.tertiaryColor(tertiaryColor);
    	if ($$props.secondary === void 0 && $$bindings.secondary && secondary !== void 0) $$bindings.secondary(secondary);
    	if ($$props.tooltipDirection === void 0 && $$bindings.tooltipDirection && tooltipDirection !== void 0) $$bindings.tooltipDirection(tooltipDirection);
    	if ($$props.relativeTooltip === void 0 && $$bindings.relativeTooltip && relativeTooltip !== void 0) $$bindings.relativeTooltip(relativeTooltip);
    	$$result.css.add(css$1);

    	return `<button class="${[
		"spectrum-ActionButton spectrum-ActionButton--size" + escape(size, true) + " svelte-hl54dl",
		(iconOnly ? "spectrum-ActionButton-iconOnly" : "") + ' ' + (groupItem ? "spectrum-ActionGroup-item" : "") + ' ' + (emphasized ? "spectrum-ActionButton--emphasized" : "") + ' ' + (quiet ? "spectrum-ActionButton--quiet" : "") + ' ' + (isSelected ? "is-selected" : "") + ' ' + (secondary ? "secondary" : "") + ' ' + (relativeTooltip ? "u-tooltip-showOnHover" : "")
	].join(' ').trim()}" ${disabled ? "disabled" : ""} style="${"--iconColor: " + escape(
		iconColor
		? iconColor
		: "var(--spectrum-actionbutton-m-texticon-icon-color-hover, var(--spectrum-alias-component-icon-color-hover))",
		true
	) + "; --secondary-color: " + escape(secondaryColor, true) + "; --tertiary-color: " + escape(tertiaryColor, true) + "; " + escape(margin ? `margin: ${margin}` : "", true) + "; --width: " + escape(width ? width : "inherit", true) + ";"}">${hold
	? `<svg class="${escape(null_to_empty(`spectrum-Icon spectrum-UIIcon-CornerTriangle${size == "S" ? "75" : "100"} spectrum-ActionButton-hold`), true) + " svelte-hl54dl"}" focusable="false" aria-hidden="true"><use${add_attribute("xlink:href", `#spectrum-css-icon-CornerTriangle${size == "S" ? "75" : "100"}`, 0)}></use></svg>`
	: ``}
    ${iconName
	? `<svg class="${"spectrum-Icon spectrum-Icon--size" + escape(size, true) + " svelte-hl54dl"}" focusable="false" aria-hidden="true" aria-label="Edit"><use xlink:href="${"#spectrum-icon-18-" + escape(iconName, true)}"></use></svg>`
	: ``}
    ${label && !iconOnly
	? `<span class="spectrum-ActionButton-label svelte-hl54dl">${escape(label)}</span>`
	: ``}
    ${slots.default ? slots.default({}) : ``}
    ${relativeTooltip
	? `<div class="${"spectrum-Tooltip spectrum-Tooltip--" + escape(tooltipDirection === "auto" ? "top" : tooltipDirection, true) + " svelte-hl54dl"}"><span class="spectrum-Tooltip-label">${escape(label)}</span>
            <span class="spectrum-Tooltip-tip"></span></div>`
	: ``}</button>
${iconOnly || !hideTooltip && !relativeTooltip
	? `${validate_component(Tooltip$1, "Tooltip").$$render(
			$$result,
			{
				relative: true,
				text: label,
				align: tooltipDirection
			},
			{},
			{}
		)}`
	: ``}`;
    });

    /* src/components/Tooltip.svelte generated by Svelte v3.59.2 */

    const css = {
    	code: ".spectrum-Tooltip.svelte-13ed4ik{position:fixed;z-index:99;max-width:75vw;pointer-events:none}.spectrum-Tooltip-label.svelte-13ed4ik{overflow-wrap:word-break}.spectsrum-Tooltip.vertical.svelte-13ed4ik{writing-mode:vertical-rl;padding:var(--spectrum-global-dimension-size-125) var(--spectrum-global-dimension-size-50)}",
    	map: "{\"version\":3,\"file\":\"Tooltip.svelte\",\"sources\":[\"Tooltip.svelte\"],\"sourcesContent\":[\"<script>\\n    export let text = \\\"\\\";\\n    $: breakText = text.replace(/-/g, '-<wbr>').replace(/_/g, '-<wbr>');\\n    export let align = \\\"auto\\\";\\n    export let vertical;\\n    export let relative;\\n    $: direction = align;\\n    let tooltip;\\n    let isOpen = false;\\n    let top, left, offsetX = 0, offsetY = 0;\\n    $:trigger = tooltip ? tooltip.previousElementSibling : undefined;\\n    $: if(trigger){\\n        //trigger.addEventListener('resize', position(trigger, tooltip, direction))\\n        trigger.addEventListener('mouseover', handleMouseover);\\n        trigger.addEventListener('mouseout', handleMouseout);\\n        window.addEventListener('blur', handleMouseout);\\n        window.addEventListener('focus', handleMouseout);\\n\\n        //position(trigger, tooltip, direction);\\n    } \\n    $: if(isOpen){\\n        position(trigger, tooltip);\\n    }\\n    const position = (target, element) =>{\\n        let triggerDOMrect = target.getBoundingClientRect();\\n        let triggerTop = triggerDOMrect.top;\\n        let triggerLeft = triggerDOMrect.left;\\n        let triggerWidth = target.offsetWidth;\\n        let triggerHeight = target.offsetHeight\\n        \\n        let tipWidth = element.offsetWidth;\\n        let tipHeight = element.offsetHeight\\n        if(align === \\\"auto\\\") getDirection(target, element);\\n        switch(direction){ \\n            case \\\"left\\\" :\\n                left = triggerLeft - tipWidth;\\n                top = triggerTop + triggerHeight/2 - tipHeight/2;\\n                break; \\n            case \\\"right\\\" :\\n                left = triggerLeft + triggerWidth;\\n                top = triggerTop + triggerHeight/2 - tipHeight/2; \\n                break;\\n            case \\\"top\\\" : \\n                left = triggerLeft + triggerWidth/2 - tipWidth/2;\\n                top = triggerTop - tipHeight; \\n                break;\\n            case \\\"bottom\\\":\\n                left = triggerLeft + triggerWidth/2 - tipWidth/2;\\n                top = triggerTop + triggerHeight; \\n                break;\\n        }\\n        setWindowOffsets(element);\\n        top = top + offsetY;\\n        left = left + offsetX;\\n    }\\n    function setWindowOffsets(element){  \\n        let tipWidth = element.offsetWidth;\\n        let tipHeight = element.offsetHeight;\\n        \\n        if(tipHeight > innerHeight){ \\n            top = innerHeight/2 - tipHeight/2;\\n        } \\n        if(tipWidth > innerWidth){\\n            left = innerWidth/2 - tipWidth/2; \\n        }\\n        let bottomOverflow = Math.max(0, top + tipHeight - innerHeight);\\n        let topOverflow = Math.min(0, top);     \\n        let rightOverflow = Math.max(0, left + tipWidth - innerWidth);    \\n        let leftOverflow = Math.min(0, left)\\n        offsetY = !topOverflow ? -bottomOverflow : -top;\\n        offsetX = !leftOverflow ? -rightOverflow : -left;\\n    }\\n    function getDirection(target, element){\\n        try{ \\n            let triggerDOMrect = target.getBoundingClientRect();\\n            let triggerTop = triggerDOMrect.top;\\n            let triggerLeft = triggerDOMrect.left;\\n            let triggerWidth = target.offsetWidth;\\n            let triggerHeight = target.offsetHeight\\n            let tipWidth = element.offsetWidth;\\n            let tipHeight = element.offsetHeight\\n            \\n            const offsets = {\\n                \\\"top\\\" : triggerTop,\\n                \\\"right\\\" : innerWidth - (triggerLeft + triggerWidth),\\n                \\\"bottom\\\" : innerHeight - (triggerTop + triggerHeight), \\n                \\\"left\\\" : triggerLeft\\n            } \\n            const spaces = {\\n                \\\"top\\\" : offsets.top - tipHeight,\\n                \\\"right\\\" : offsets.right - tipWidth,\\n                \\\"bottom\\\" : offsets.bottom - tipHeight,\\n                \\\"left\\\" : offsets.left - tipWidth\\n            }\\n            direction = Object.keys(spaces).reduce((a, b) => spaces[a] > spaces[b] ? a : b);\\n        }catch(error){\\n           alert(error)\\n        }\\n    }\\n    const handleMouseover = ()=> isOpen = true;\\n    const handleMouseout = () => isOpen = false;\\n    \\n    let innerWidth;\\n    $: vertical = innerWidth < 134;\\n</script>\\n<svelte:window bind:innerWidth />\\n{#if text}\\n    <span \\n        bind:this={tooltip} \\n        class=\\\"spectrum-Tooltip spectrum-Tooltip--{direction}\\\" \\n        class:is-open={isOpen} \\n        class:vertical\\n        class:relative\\n        style=\\\"top: {top}px; left: {left}px\\\">\\n        <span class=\\\"spectrum-Tooltip-label\\\">{@html breakText}</span>\\n        {#if direction === \\\"top\\\" || direction === \\\"bottom\\\"}<span class=\\\"spectrum-Tooltip-tip\\\" style={`left: calc(50% - ${offsetX}px)`}></span>{/if}\\n        {#if direction === \\\"left\\\" || direction === \\\"right\\\"}<span class=\\\"spectrum-Tooltip-tip\\\" style={`top: calc(50% - ${offsetY}px)`}></span>{/if}\\n    </span> \\n{/if}\\n<style>     \\n.spectrum-Tooltip{\\n    position: fixed;\\n    z-index: 99;\\n    max-width: 75vw;\\n    pointer-events: none;\\n}\\n.spectrum-Tooltip-label{\\n    overflow-wrap: word-break;\\n}\\n.spectsrum-Tooltip.vertical{\\n    writing-mode: vertical-rl; \\n    padding: var(--spectrum-global-dimension-size-125) var(--spectrum-global-dimension-size-50);\\n}\\n</style>\"],\"names\":[],\"mappings\":\"AAwHA,gCAAiB,CACb,QAAQ,CAAE,KAAK,CACf,OAAO,CAAE,EAAE,CACX,SAAS,CAAE,IAAI,CACf,cAAc,CAAE,IACpB,CACA,sCAAuB,CACnB,aAAa,CAAE,UACnB,CACA,kBAAkB,wBAAS,CACvB,YAAY,CAAE,WAAW,CACzB,OAAO,CAAE,IAAI,oCAAoC,CAAC,CAAC,IAAI,mCAAmC,CAC9F\"}"
    };

    const Tooltip = create_ssr_component(($$result, $$props, $$bindings, slots) => {
    	let breakText;
    	let direction;
    	let trigger;
    	let { text = "" } = $$props;
    	let { align = "auto" } = $$props;
    	let { vertical } = $$props;
    	let { relative } = $$props;
    	let tooltip;
    	let isOpen = false;
    	let top, left, offsetX = 0, offsetY = 0;

    	const position = (target, element) => {
    		let triggerDOMrect = target.getBoundingClientRect();
    		let triggerTop = triggerDOMrect.top;
    		let triggerLeft = triggerDOMrect.left;
    		let triggerWidth = target.offsetWidth;
    		let triggerHeight = target.offsetHeight;
    		let tipWidth = element.offsetWidth;
    		let tipHeight = element.offsetHeight;
    		if (align === "auto") getDirection(target, element);

    		switch (direction) {
    			case "left":
    				left = triggerLeft - tipWidth;
    				top = triggerTop + triggerHeight / 2 - tipHeight / 2;
    				break;
    			case "right":
    				left = triggerLeft + triggerWidth;
    				top = triggerTop + triggerHeight / 2 - tipHeight / 2;
    				break;
    			case "top":
    				left = triggerLeft + triggerWidth / 2 - tipWidth / 2;
    				top = triggerTop - tipHeight;
    				break;
    			case "bottom":
    				left = triggerLeft + triggerWidth / 2 - tipWidth / 2;
    				top = triggerTop + triggerHeight;
    				break;
    		}

    		setWindowOffsets(element);
    		top = top + offsetY;
    		left = left + offsetX;
    	};

    	function setWindowOffsets(element) {
    		let tipWidth = element.offsetWidth;
    		let tipHeight = element.offsetHeight;

    		if (tipHeight > innerHeight) {
    			top = innerHeight / 2 - tipHeight / 2;
    		}

    		if (tipWidth > innerWidth) {
    			left = innerWidth / 2 - tipWidth / 2;
    		}

    		let bottomOverflow = Math.max(0, top + tipHeight - innerHeight);
    		let topOverflow = Math.min(0, top);
    		let rightOverflow = Math.max(0, left + tipWidth - innerWidth);
    		let leftOverflow = Math.min(0, left);
    		offsetY = !topOverflow ? -bottomOverflow : -top;
    		offsetX = !leftOverflow ? -rightOverflow : -left;
    	}

    	function getDirection(target, element) {
    		try {
    			let triggerDOMrect = target.getBoundingClientRect();
    			let triggerTop = triggerDOMrect.top;
    			let triggerLeft = triggerDOMrect.left;
    			let triggerWidth = target.offsetWidth;
    			let triggerHeight = target.offsetHeight;
    			let tipWidth = element.offsetWidth;
    			let tipHeight = element.offsetHeight;

    			const offsets = {
    				"top": triggerTop,
    				"right": innerWidth - (triggerLeft + triggerWidth),
    				"bottom": innerHeight - (triggerTop + triggerHeight),
    				"left": triggerLeft
    			};

    			const spaces = {
    				"top": offsets.top - tipHeight,
    				"right": offsets.right - tipWidth,
    				"bottom": offsets.bottom - tipHeight,
    				"left": offsets.left - tipWidth
    			};

    			direction = Object.keys(spaces).reduce((a, b) => spaces[a] > spaces[b] ? a : b);
    		} catch(error) {
    			alert(error);
    		}
    	}

    	const handleMouseover = () => isOpen = true;
    	const handleMouseout = () => isOpen = false;
    	let innerWidth;
    	if ($$props.text === void 0 && $$bindings.text && text !== void 0) $$bindings.text(text);
    	if ($$props.align === void 0 && $$bindings.align && align !== void 0) $$bindings.align(align);
    	if ($$props.vertical === void 0 && $$bindings.vertical && vertical !== void 0) $$bindings.vertical(vertical);
    	if ($$props.relative === void 0 && $$bindings.relative && relative !== void 0) $$bindings.relative(relative);
    	$$result.css.add(css);
    	breakText = text.replace(/-/g, '-<wbr>').replace(/_/g, '-<wbr>');
    	direction = align;
    	trigger = undefined;

    	{
    		if (trigger) {
    			//trigger.addEventListener('resize', position(trigger, tooltip, direction))
    			trigger.addEventListener('mouseover', handleMouseover);

    			trigger.addEventListener('mouseout', handleMouseout);
    			window.addEventListener('blur', handleMouseout);
    			window.addEventListener('focus', handleMouseout);
    		} //position(trigger, tooltip, direction);
    	}

    	{
    		if (isOpen) {
    			position(trigger, tooltip);
    		}
    	}

    	vertical = innerWidth < 134;

    	return `
${text
	? `<span class="${[
			"spectrum-Tooltip spectrum-Tooltip--" + escape(direction, true) + " svelte-13ed4ik",
			(isOpen ? "is-open" : "") + ' ' + (vertical ? "vertical" : "") + ' ' + (relative ? "relative" : "")
		].join(' ').trim()}" style="${"top: " + escape(top, true) + "px; left: " + escape(left, true) + "px"}"${add_attribute("this", tooltip, 0)}><span class="spectrum-Tooltip-label svelte-13ed4ik"><!-- HTML_TAG_START -->${breakText}<!-- HTML_TAG_END --></span>
        ${direction === "top" || direction === "bottom"
		? `<span class="spectrum-Tooltip-tip"${add_attribute("style", `left: calc(50% - ${offsetX}px)`, 0)}></span>`
		: ``}
        ${direction === "left" || direction === "right"
		? `<span class="spectrum-Tooltip-tip"${add_attribute("style", `top: calc(50% - ${offsetY}px)`, 0)}></span>`
		: ``}</span>`
	: ``}`;
    });

    exports.ActionButton = ActionButton;
    exports.Tooltip = Tooltip;

    return exports;

})({}, Tooltip$1);
